@@ -31,19 +31,23 @@
 #define SOFTWARE_CATEGORY_URN_PREFIX "urn:software-category:"
 #define THEME_ICON_URN_PREFIX        "urn:theme-icon:"
 
-static void     miner_applications_finalize          (GObject              *object);
-static void     miner_applications_constructed       (GObject              *object);
+static void     miner_applications_finalize                (GObject              *object);
+static void     miner_applications_constructed             (GObject              *object);
 
-static gboolean miner_applications_check_file        (TrackerMinerFS       *fs,
-                                                      GFile                *file);
-static gboolean miner_applications_check_directory   (TrackerMinerFS       *fs,
-                                                      GFile                *file);
-static gboolean miner_applications_process_file      (TrackerMinerFS       *fs,
-                                                      GFile                *file,
-                                                      TrackerSparqlBuilder *sparql,
-                                                      GCancellable         *cancellable);
-static gboolean miner_applications_monitor_directory (TrackerMinerFS       *fs,
-                                                      GFile                *file);
+static gboolean miner_applications_check_file              (TrackerMinerFS       *fs,
+                                                            GFile                *file);
+static gboolean miner_applications_check_directory         (TrackerMinerFS       *fs,
+                                                            GFile                *file);
+static gboolean miner_applications_process_file            (TrackerMinerFS       *fs,
+                                                            GFile                *file,
+                                                            TrackerSparqlBuilder *sparql,
+                                                            GCancellable         *cancellable);
+static gboolean miner_applications_process_file_attributes (TrackerMinerFS       *fs,
+                                                            GFile                *file,
+                                                            TrackerSparqlBuilder *sparql,
+                                                            GCancellable         *cancellable);
+static gboolean miner_applications_monitor_directory       (TrackerMinerFS       *fs,
+                                                            GFile                *file);
 
 static GQuark miner_applications_error_quark = 0;
 
@@ -73,6 +77,7 @@ tracker_miner_applications_class_init (TrackerMinerApplicationsClass *klass)
 	miner_fs_class->check_directory = miner_applications_check_directory;
 	miner_fs_class->monitor_directory = miner_applications_monitor_directory;
 	miner_fs_class->process_file = miner_applications_process_file;
+	miner_fs_class->process_file_attributes = miner_applications_process_file_attributes;
 
 	miner_applications_error_quark = g_quark_from_static_string ("TrackerMinerApplications");
 }
@@ -224,7 +229,7 @@ process_directory (ProcessApplicationData  *data,
 
 	path = g_file_get_path (data->file);
 	uri = g_file_get_uri (data->file);
-	urn = tracker_uri_printf_escaped ("urn:applications-dir:%s", path);
+	urn = tracker_sparql_escape_uri_printf ("urn:applications-dir:%s", path);
 
 	tracker_sparql_builder_insert_silent_open (sparql, TRACKER_MINER_FS_GRAPH_URN);
 
@@ -299,7 +304,7 @@ process_desktop_file (ProcessApplicationData  *data,
 	}
 
 	if (name && g_ascii_strcasecmp (type, "Directory") == 0) {
-		gchar *canonical_uri = tracker_uri_printf_escaped (SOFTWARE_CATEGORY_URN_PREFIX "%s", path);
+		gchar *canonical_uri = tracker_sparql_escape_uri_printf (SOFTWARE_CATEGORY_URN_PREFIX "%s", path);
 		gchar *icon = g_key_file_get_string (key_file, GROUP_DESKTOP_ENTRY, "Icon", NULL);
 
 		uri = canonical_uri;
@@ -454,7 +459,7 @@ process_desktop_file (ProcessApplicationData  *data,
 				/* Sanitize category */
 				g_strstrip (cat);
 
-				cat_uri = tracker_uri_printf_escaped (SOFTWARE_CATEGORY_URN_PREFIX "%s", cat);
+				cat_uri = tracker_sparql_escape_uri_printf (SOFTWARE_CATEGORY_URN_PREFIX "%s", cat);
 
 				/* There are also .desktop
 				 * files that describe these categories, but we can handle
@@ -615,6 +620,22 @@ miner_applications_process_file (TrackerMinerFS       *fs,
 	return TRUE;
 }
 
+static gboolean
+miner_applications_process_file_attributes (TrackerMinerFS       *fs,
+                                            GFile                *file,
+                                            TrackerSparqlBuilder *sparql,
+                                            GCancellable         *cancellable)
+{
+	gchar *uri;
+
+	/* We don't care about file attribute changes here */
+	uri = g_file_get_uri (file);
+	g_debug ("Ignoring file attribute changes in '%s'", uri);
+	g_free (uri);
+
+	return FALSE;
+}
+
 TrackerMiner *
 tracker_miner_applications_new (void)
 {
