@@ -49,16 +49,11 @@ typedef void (* TrackerStoreSparqlUpdateCallback)      (GError          *error,
 typedef void (* TrackerStoreSparqlUpdateBlankCallback) (GPtrArray       *blank_nodes,
                                                         GError          *error,
                                                         gpointer         user_data);
-typedef void (* TrackerStoreCommitCallback)            (gpointer         user_data);
 typedef void (* TrackerStoreTurtleCallback)            (GError          *error,
                                                         gpointer         user_data);
 
 void         tracker_store_init                   (void);
 void         tracker_store_shutdown               (void);
-void         tracker_store_queue_commit           (TrackerStoreCommitCallback callback,
-                                                   const gchar   *client_id,
-                                                   gpointer       user_data,
-                                                   GDestroyNotify destroy);
 void         tracker_store_sparql_query           (const gchar   *sparql,
                                                    TrackerStorePriority priority,
                                                    TrackerStoreSparqlQueryInThread in_thread,
@@ -68,7 +63,6 @@ void         tracker_store_sparql_query           (const gchar   *sparql,
                                                    GDestroyNotify destroy);
 void         tracker_store_sparql_update          (const gchar   *sparql,
                                                    TrackerStorePriority priority,
-                                                   gboolean       batch,
                                                    TrackerStoreSparqlUpdateCallback callback,
                                                    const gchar   *client_id,
                                                    gpointer       user_data,
@@ -81,6 +75,7 @@ void         tracker_store_sparql_update_blank    (const gchar   *sparql,
                                                    GDestroyNotify destroy);
 void         tracker_store_queue_turtle_import    (GFile         *file,
                                                    TrackerStoreTurtleCallback callback,
+                                                   const gchar   *client_id,
                                                    gpointer       user_data,
                                                    GDestroyNotify destroy);
 
